declare default element namespace 'http://пф.рф/СИоРУН/2021-12-17';
declare namespace УТ = "http://пф.рф/УТ/2017-08-21";
declare namespace АФ = "http://пф.рф/АФ/2018-12-07";
declare namespace map = "http://www.w3.org/2005/xpath-functions/map";
declare variable $document as document-node() external;
declare variable $root := $document/ЭДПФР;
declare variable $info:=$root/СИоРУН;
declare function local:get-result($result as item()*) as item()*
{
(: v1.0.0 :)
if ($result)
then $result
else <Результат>0</Результат>

};
declare function local:result($node as node()?, $expected as xs:anyAtomicType, $objectName as xs:string, $objectValue as xs:anyAtomicType) as node()
{
(: v2.0.0 :)
<Результат>
  <ПутьДоЭлемента>{fn:replace(fn:path($node), "Q\{.+?\}", "")}</ПутьДоЭлемента>
  <ОжидаемоеЗначение>{$expected}</ОжидаемоеЗначение>
  <Объект>
    <Наименование>{$objectName}</Наименование>
    <Значение>{$objectValue}</Значение>
  </Объект>
</Результат>

};
declare function local:blank($element) as xs:boolean
{
(: v2.0.0 :)
fn:normalize-space($element) = ""

};
declare function local:get-info($person as element()) as xs:string
{
(: v2.0.0 :)
let $insuranceNumber := $person/УТ:СНИЛС
let $fullName := local:full-name($person)
let $info := fn:string-join(($insuranceNumber, $fullName), ", ")
return $info

};
declare function local:full-name($person as element()) as xs:string
{
(: v2.0.0 :)
let $first := $person/УТ:ФИО/УТ:Имя
let $last := $person/УТ:ФИО/УТ:Фамилия
let $patr := $person/УТ:ФИО/УТ:Отчество
return if (local:blank($patr))
       then fn:string-join(($last, $first), " ")
       else fn:string-join(($last, $first, $patr), " ")

};
declare function local:ddmmyyyy-to-date($dateString as xs:string?) as xs:date?
{
(: v2.0.0 :)
if (empty($dateString))
then ()
else if (not(matches($dateString,
                     '^\D*(\d{2})\D*(\d{2})\D*(\d{4})\D*$')))
     then error(QName("http://err", "err"), "Missing product number.")
     else xs:date(replace($dateString,
                          '^\D*(\d{2})\D*(\d{2})\D*(\d{4})\D*$',
                          '$3-$2-$1'))

};
<БлокПроверок ID="ВВ.СИоРУН.1" name="Блок проверок документов по форме 'Форма сбора информации о заработной плате работников государственных и муниципальных учреждений науки и высшего образования'">
<Проверка ID="1">
<Описание>В отчете не может быть полного дубликата строк</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( let $range := $info/СЗП/Период
                  let $distinct := for $val in distinct-values($range)
                                   return $val[count($range[. = $val]) > 1]
                  where not($distinct = ())
                  return for $i in $distinct
                         return for $person in $range/Работник
                                let $personInfo := local:get-info($person)
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="2">
<Описание>Если элемент Вид договора принимает значение ‘4’, то элемент Срок договора принимает значение ‘2’</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $type := $salary/ВидДоговора
                                let $date := $salary/СрокДоговора
                                where ($type = 4)
                                      and ($date != 2)
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="3">
<Описание>Если элемент Вид договора принимает значение ‘4’, то элемент Стаж принимает значение 0</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         let $exp := $person/Стаж
                         return for $salary in $person/СЗПД
                                let $type := $salary/ВидДоговора
                                where ($type = 4)
                                      and ($exp != 0)
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="4">
<Описание>Значение элемента Стаж, должно быть не более значения элемента Возраст</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         let $exp := xs:integer($person/Стаж)
                         let $age := xs:integer($person/Возраст)
                         where ($exp > $age)
                         return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="5">
<Описание>Дата начала периода должна быть больше или равна дате начала месяца и меньше или равна дате конца месяца отчетного периода</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  let $month := xs:integer($range/ОтчетныйПериод/Месяц)
                  let $year :=  xs:integer($range/ОтчетныйПериод/Год)
                  let $formatedMonth := if ($month < 10)
                                        then format-integer($month, "00")
                                        else $month
                  let $isLeapYear := ($year mod 4 = 0
                                      and $year mod 100 != 0)
                                      or $year mod 400 = 0
                  let $maxDayInMonth := if ($month = 2
                                            and $isLeapYear)
                                        then 29
                                        else (31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31)[$month]
                  let $firstDay := xs:date(string-join(($year, $formatedMonth, "01"), "-"))
                  let $lastDay := xs:date(string-join(($year, $formatedMonth, $maxDayInMonth), "-"))
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $startDate := local:ddmmyyyy-to-date($salary/ПериодРаботы/ДатаНачалаПериода)
                                where ($startDate < $firstDay)
                                       or ($startDate > $lastDay)
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="6">
<Описание>Дата окончания периода должна быть меньше или равна дате конца месяца и больше или равна дате начала месяца отчетного периода</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  let $month := xs:integer($range/ОтчетныйПериод/Месяц)
                  let $year :=  xs:integer($range/ОтчетныйПериод/Год)
                  let $formatedMonth := if ($month < 10)
                                        then format-integer($month, "00")
                                        else $month
                  let $isLeapYear := ($year mod 4 = 0
                                      and $year mod 100 != 0)
                                      or $year mod 400 = 0
                  let $maxDayInMonth := if ($month = 2
                                            and $isLeapYear)
                                        then 29
                                        else (31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31)[$month]
                  let $firstDay := xs:date(string-join(($year, $formatedMonth, "01"), "-"))
                  let $lastDay := xs:date(string-join(($year, $formatedMonth, $maxDayInMonth), "-"))
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $endDate := local:ddmmyyyy-to-date($salary/ПериодРаботы/ДатаОкончанияПериода)
                                where ($endDate < $firstDay)
                                       or ($endDate > $lastDay)
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="7">
<Описание>Дата окончания периода не может быть меньше Даты начала периода</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $startDate := local:ddmmyyyy-to-date($salary/ПериодРаботы/ДатаНачалаПериода)
                                let $endDate := local:ddmmyyyy-to-date($salary/ПериодРаботы/ДатаОкончанияПериода)
                                where ($endDate < $startDate)
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="8">
<Описание>Если элемент Вид договора принимает значение ‘4’, то элемент Должность отсутствует. В других случаях элемент Должность обязателен</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $type := $salary/ВидДоговора
                                let $position := $salary/Должность
                                where (($type = 4)
                                        and (exists($position) or not(local:blank($position))))
                                        or (($type != 4)
                                            and (empty($position) or local:blank($position)))
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="9">
<Описание>Если элемент Должность отсутствует, то элемент ККП ‘600’</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $position := $salary/Должность
                                let $code := $salary/ККП
                                where (empty($position) or local:blank($position))
                                      and ($code != "600")
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="10">
<Описание>Если элемент Вид договора принимает значение ‘4’, то элемент Ставка отсутствует, в остальных случаях элемент Ставка обязателен.</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $type := $salary/ВидДоговора
                                let $rate := $salary/Ставка
                                where (($type = 4)
                                      and (exists($rate) or not(local:blank($rate))))
                                      or (not($type = 4)
                                      and (empty($rate) or local:blank($rate)))
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="11">
<Описание>Если элемент Вид договора принимает значение ‘4’, то элемент ТарифнаяСтавка принимает значение 0.00</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $type := $salary/ВидДоговора
                                let $rate := $salary/ТарифнаяСтавка
                                where ($type = 4)
                                      and ($rate != "0.00")
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="12">
<Описание>Если элемент Вид договора принимает значение ‘4’, то элементы РабВремяНорма и РабВремяФакт принимают значение 0.00</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $type := $salary/ВидДоговора
                                let $rate1 := $salary/РабВремяНорма
                                let $rate2 := $salary/РабВремяФакт
                                where ($type = 4)
                                      and (($rate1 != "0.00") or ($rate2 != "0.00"))
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="13">
<Описание>Если элемент Вид договора принимает значение ‘4’, то элементы ОУТ, Категория, Ученая степень и Ученое звание отсутствуют</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $type := $salary/ВидДоговора
                                let $el1 := $salary/ОУТ
                                let $el2 := $salary/Категория
                                let $el3 := $salary/УченаяСтепень
                                let $el4 := $salary/УченоеЗвание
                                where ($type = 4)
                                      and ((exists($el1) or not(local:blank($el1)))
                                      or (exists($el2) or not(local:blank($el2)))
                                      or (exists($el3) or not(local:blank($el3)))
                                      or (exists($el4) or not(local:blank($el4))))
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="14">
<Описание>Если элемент ККП принимает значение ‘311’, то элемент Должность принимает одно из следующих значений ‘Главный научный сотрудник’, ‘Ведущий научный сотрудник’, ‘Старший научный сотрудник’, ‘Научный сотрудник’, ‘Младший научный сотрудник’</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $position := $salary/Должность
                                let $code := $salary/ККП
                                where ($code = "311")
                                      and not($position = ("Главный научный сотрудник", "Ведущий научный сотрудник", "Старший научный сотрудник", "Научный сотрудник", "Младший научный сотрудник"))
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="15">
<Описание>Если элемент ККП принимает значение ‘312’, то элемент Должность принимает одно из следующих значений ‘Главный научный сотрудник’, ‘Ведущий научный сотрудник’, ‘Старший научный сотрудник’</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $position := $salary/Должность
                                let $code := $salary/ККП
                                where ($code = "312")
                                      and not($position = ("Главный научный сотрудник", "Ведущий научный сотрудник", "Старший научный сотрудник"))
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="16">
<Описание>Если элемент ККП принимает значение ‘313’, то элемент Должность принимает одно из следующих значений ‘Научный сотрудник’, ‘Младший научный сотрудник’</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $position := $salary/Должность
                                let $code := $salary/ККП
                                where ($code = "313")
                                      and not($position = ("Научный сотрудник", "Младший научный сотрудник"))
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="17">
<Описание>Если элемент ККП принимает значение ‘261’, то элемент Должность принимает одно из следующих значений ‘Декан факультета’, ‘Директор института’, ‘Заведующий кафедрой’, ‘Профессор’, ‘Доцент’, ‘Старший преподаватель’, ‘Преподаватель’, ‘Ассистент’</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $position := $salary/Должность
                                let $code := $salary/ККП
                                where ($code = "261")
                                      and not($position = ("Декан факультета", "Директор института", "Заведующий кафедрой", "Профессор", "Доцент", "Старший преподаватель", "Преподаватель", "Ассистент"))
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="18">
<Описание>Если элемент Вид договора принимает значение ‘1’, то сумма длин периодов по одному СНИЛС в рамках одной организации за отчетный период, не должна превышать количество дней в месяце отчетного периода</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  let $month := xs:integer($range/ОтчетныйПериод/Месяц)
                  let $year :=  xs:integer($range/ОтчетныйПериод/Год)
                  let $formatedMonth := if ($month < 10)
                                        then format-integer($month, "00")
                                        else $month
                  let $isLeapYear := ($year mod 4 = 0
                                      and $year mod 100 != 0)
                                      or $year mod 400 = 0
                  let $maxDayInMonth := if ($month = 2
                                            and $isLeapYear)
                                        then 29
                                        else (31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31)[$month]
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $startDate := local:ddmmyyyy-to-date($salary/ПериодРаботы/ДатаНачалаПериода)
                                let $endDate := local:ddmmyyyy-to-date($salary/ПериодРаботы/ДатаОкончанияПериода)
                                let $durDate := $endDate - $startDate
                                let $sumDate := abs(days-from-duration($durDate)) + 1
                                where $sumDate > $maxDayInMonth
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="19">
<Описание>Сумма длин периодов умноженная на 16 должна быть больше или равна значению суммы элемента РабВремяНорма по одному СНИЛС в рамках одной организации за отчетный период</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $startDate := local:ddmmyyyy-to-date($salary/ПериодРаботы/ДатаНачалаПериода)
                                let $endDate := local:ddmmyyyy-to-date($salary/ПериодРаботы/ДатаОкончанияПериода)
                                let $workHours := $salary/РабВремяНорма
                                let $durDate := $endDate - $startDate
                                let $sumDate := abs(days-from-duration($durDate)) + 1
                                let $prodDate := $sumDate * 16
                                where $prodDate < $workHours
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="20">
<Описание>Значение элемента НачисленияТариф с погрешностью в диапазоне +-100% должно быть равно произведению элементов ТарифнаяСтавка*Ставка</Описание>
<РезультатЗапроса>
{
(: v2.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $val1 := $salary/НачисленияТариф
                                let $val2 := $salary/ТарифнаяСтавка * $salary/Ставка
                                where ($val2 > ($val1 * 2))
                                      or ($val1 > ($val2 * 2))
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="21">
<Описание>Значение элемента НачисленияИтого должно быть равно сумме значений элементов с 1.1.2.1.2.6.16 НачисленияТариф по 1.1.2.1.2.6.31 НачисленияПремииИные и с 1.1.2.1.2.6.34 НачисленияОтпуск по 1.1.2.1.2.6.45 ДоплатаГПХ</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $sum1 := $salary/НачисленияИтого
                                let $elements := ($salary/НачисленияТариф,
                                                  $salary/НачисленияОУТ,
                                                  $salary/ДоплатаСверхур,
                                                  $salary/ДоплатаСовмещение,
                                                  $salary/ДоплатаСМ,
                                                  $salary/ДоплатаТариф,
                                                  $salary/ДоплатаКомпенсИная,
                                                  $salary/ДоплатаРезРаб,
                                                  $salary/ДоплатаКвалКат,
                                                  $salary/ДоплатаПЗ,
                                                  $salary/ДоплатаУС,
                                                  $salary/ДоплатаУЗ,
                                                  $salary/ДоплатаСтимул,
                                                  $salary/ДоплатаСтаж,
                                                  $salary/НачисленияПремии,
                                                  $salary/НачисленияПремииИные,
                                                  $salary/НачисленияОтпуск,
                                                  $salary/НачисленияОтпускИной,
                                                  $salary/ДоплатаКомпенсОтп,
                                                  $salary/НачисленияОбуч,
                                                  $salary/ДоплатаСредЗараб,
                                                  $salary/ВыплатыПрочие,
                                                  $salary/ДоплатаРайон,
                                                  $salary/ДоплатаПустБезводн,
                                                  $salary/ДоплатаВысГорРн,
                                                  $salary/ДоплатаРКС,
                                                  $salary/НачисленияМатПомощь,
                                                  $salary/ДоплатаГПХ)
                                let $sum2 := sum($elements)
                                where $sum1 != $sum2
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="22">
<Описание>Если графа 17 (ВидДоговора) принимает значение 4, то графы 33-61 принимают значение 0.00</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $type := $salary/ВидДоговора
                                where ($type = 4)
                                      and (($salary/НачисленияТариф != "0.00")
                                      or ($salary/НачисленияОУТ != "0.00")
                                      or ($salary/ДоплатаСверхур != "0.00")
                                      or ($salary/ДоплатаСовмещение != "0.00")
                                      or ($salary/ДоплатаСМ != "0.00")
                                      or ($salary/ДоплатаТариф != "0.00")
                                      or ($salary/ДоплатаКомпенсИная != "0.00")
                                      or ($salary/ДоплатаРезРаб != "0.00")
                                      or ($salary/ДоплатаКвалКат != "0.00")
                                      or ($salary/ДоплатаПЗ != "0.00")
                                      or ($salary/ДоплатаУС != "0.00")
                                      or ($salary/ДоплатаУЗ != "0.00")
                                      or ($salary/ДоплатаСтимул != "0.00")
                                      or ($salary/ДоплатаСтаж != "0.00")
                                      or ($salary/НачисленияПремии != "0.00")
                                      or ($salary/НачисленияПремииИные != "0.00")
                                      or ($salary/ДоплатаНаставничество != "0.00")
                                      or ($salary/ДоплатаМолодСпец != "0.00")
                                      or ($salary/НачисленияОтпуск != "0.00")
                                      or ($salary/НачисленияОтпускИной != "0.00")
                                      or ($salary/ДоплатаКомпенсОтп != "0.00")
                                      or ($salary/НачисленияОбуч != "0.00")
                                      or ($salary/ДоплатаСредЗараб != "0.00")
                                      or ($salary/ВыплатыПрочие != "0.00")
                                      or ($salary/ДоплатаРайон != "0.00")
                                      or ($salary/ДоплатаПустБезводн != "0.00")
                                      or ($salary/ДоплатаВысГорРн != "0.00")
                                      or ($salary/ДоплатаРКС != "0.00")
                                      or ($salary/НачисленияМатПомощь != "0.00"))
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="23">
<Описание>Если в графе 21 (Должность) значение равно одному из значений справочника должностей, то код должен соответствовать должности по справочнику должностей (гр. 22 (ККП) = "311","312","313"  или "261")</Описание>
<РезультатЗапроса>
{
(: v2.0.0 :)
local:get-result( let $curDict := map {
    "Главный научный сотрудник": ("311", "312"),
    "Ведущий научный сотрудник": ("311", "312"),
    "Старший научный сотрудник": ("311", "312"),
    "Научный сотрудник": ("311", "313"),
    "Младший научный сотрудник": ("311", "313"),
    "Декан факультета": "261",
    "Директор института": "261",
    "Заведующий кафедрой": "261",
    "Профессор": "261",
    "Доцент": "261",
    "Старший преподаватель": "261",
    "Преподаватель": "261",
    "Ассистент": "261"
                  }
                  for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $position := upper-case($salary/Должность)
                                let $code := $salary/ККП
                                return for $key in map:keys($curDict)
                                       where ($position = upper-case($key))
                                             and not($code = map:get($curDict, $key))
                                       return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="24">
<Описание>Если элемент Вид договора принимает значение «4», то элементы Дата начала периода и Дата окончания периода отсутствуют</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $type := $salary/ВидДоговора
                                let $startDate := $salary/ПериодРаботы/ДатаНачалаПериода
                                let $endDate := $salary/ПериодРаботы/ДатаОкончанияПериода
                                where ($type = 4)
                                      and ((exists($startDate) or not(local:blank($startDate)))
                                          or (exists($endDate) or not(local:blank($endDate))))
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
<Проверка ID="25">
<Описание>Даты начала и конца периода работы могут быть пустыми при значениях элемента Вид договора равным 1, 2, или 3 только если элементы Количество рабочих часов по графику в отчетном месяце и Фактически отработанное время принимают значения 0,00</Описание>
<РезультатЗапроса>
{
(: v1.0.0 :)
local:get-result( for $range in $info/СЗП/Период
                  return for $person in $range/Работник
                         let $personInfo := local:get-info($person)
                         return for $salary in $person/СЗПД
                                let $type := $salary/ВидДоговора
                                let $startDate := $salary/ПериодРаботы/ДатаНачалаПериода
                                let $time1 := $salary/РабВремяНорма
                                let $time2 := $salary/РабВремяФакт
                                where (($type = (1, 2, 3))
                                       and (empty($startDate) or local:blank($startDate)))
                                        and (($time1 != "0.00")
                                         or ($time2 != "0.00"))
                                return local:result($person, "", "СНИЛС, ФИО", $personInfo) )
}
</РезультатЗапроса>
<КодРезультата>50</КодРезультата>
</Проверка>
</БлокПроверок>

